@@ -25,6 +25,13 @@ class Base(Page):
                 return self.delete()
         except (exc.NoContent, exc.NotFound, exc.Forbidden):
             pass
+        except (exc.BadRequest, exc.Conflict) as e:
+            if 'Job has not finished processing events' in e.msg:
+                pass
+            if 'Resource is being used' in e.msg:
+                pass
+            else:
+                raise e
 
     def get_object_role(self, role, by_name=False):
         """Lookup and return a related object role by its role field or name.
