@@ -1,4 +1,4 @@
-from awxkit.utils import PseudoNamespace, random_title, suppress, update_payload
+from awxkit.utils import PseudoNamespace, random_title, suppress, update_payload, set_payload_foreign_key_args
 from awxkit.api.resources import resources
 from awxkit.api.mixins import HasCreate
 import awxkit.exceptions as exc
@@ -19,8 +19,11 @@ class InstanceGroup(HasCreate, base.Base):
     def payload(self, **kwargs):
         payload = PseudoNamespace(name=kwargs.get('name') or
                                   'Instance Group - {}'.format(random_title()))
-        fields = ('policy_instance_percentage', 'policy_instance_minimum', 'policy_instance_list')
+        fields = ('policy_instance_percentage', 'policy_instance_minimum', 'policy_instance_list', 'is_container_group')
         update_payload(payload, fields, kwargs)
+
+        set_payload_foreign_key_args(payload, ('credential',), kwargs)
+
         return payload
 
     def create_payload(self, name='', **kwargs):
