@@ -6,6 +6,7 @@ from awxkit.utils import (
     random_title,
     suppress,
     update_payload,
+    set_payload_foreign_key_args,
     PseudoNamespace)
 from awxkit.api.pages import Credential, Inventory, Project, UnifiedJobTemplate
 from awxkit.api.mixins import HasCreate, HasInstanceGroups, HasNotifications, HasSurvey, HasCopy, DSAdapter
@@ -101,18 +102,8 @@ class JobTemplate(
 
         if kwargs.get('project'):
             payload.update(project=kwargs.get('project').id, playbook=playbook)
-        if kwargs.get('inventory'):
-            payload.update(inventory=kwargs.get('inventory').id)
-        if kwargs.get('credential'):
-            payload.update(credential=kwargs.get('credential').id)
-        if kwargs.get('webhook_credential'):
-            webhook_cred = kwargs.get('webhook_credential')
-            if isinstance(webhook_cred, int):
-                payload.update(webhook_credential=int(webhook_cred))
-            elif hasattr(webhook_cred, 'id'):
-                payload.update(webhook_credential=webhook_cred.id)
-            else:
-                raise AttributeError("Webhook credential must either be integer of pkid or Credential object")
+
+        payload = set_payload_foreign_key_args(payload, ('inventory', 'credential', 'webhook_credential', 'execution_environment'), kwargs)
 
         return payload
 
