@@ -16,6 +16,7 @@ class Resources(object):
     _auth = 'auth/'
     _authtoken = 'authtoken/'
     _config = 'config/'
+    _config_attach = 'config/attach/'
     _credential = r'credentials/\d+/'
     _credential_access_list = r'credentials/\d+/access_list/'
     _credential_copy = r'credentials/\d+/copy/'
@@ -27,6 +28,8 @@ class Resources(object):
     _credential_types = 'credential_types/'
     _credentials = 'credentials/'
     _dashboard = 'dashboard/'
+    _execution_environment = r'execution_environments/\d+/'
+    _execution_environments = 'execution_environments/'
     _fact_view = r'hosts/\d+/fact_view/'
     _group = r'groups/\d+/'
     _group_access_list = r'groups/\d+/access_list/'
@@ -140,6 +143,7 @@ class Resources(object):
     _organization_access_list = r'organizations/\d+/access_list/'
     _organization_admins = r'organizations/\d+/admins/'
     _organization_applications = r'organizations/\d+/applications/'
+    _organization_execution_environments = r'organizations/\d+/execution_environments/'
     _organization_inventories = r'organizations/\d+/inventories/'
     _organization_users = r'organizations/\d+/users/'
     _organizations = 'organizations/'
